smartcard.wx.APDUTracerPanel.APDUTracerPanel

# ``smartcard`.`wx`.`APDUTracerPanel`.`APDUTracerPanel``

class documentation

`class APDUTracerPanel(wx.Panel, CardConnectionObserver):`

View In Hierarchy

Undocumented

Method | `__init__` | Undocumented
Method | `OnMaxLength` | Reset text buffer when max length is reached.
Method | `update` | CardConnectionObserver callback.
Instance Variable | `apdutextctrl` | Undocumented

def __init__(self, parent):

Undocumented

def OnMaxLength(self, evt):

Reset text buffer when max length is reached.

def update(self, cardconnection, ccevent):
overrides `smartcard.CardConnectionObserver.CardConnectionObserver.update`

CardConnectionObserver callback.

apdutextctrl =

Undocumented